@@ -313,6 +313,34 @@ check_command() {
     return 0
 }
 
+# Function to detect if MODs driver is loaded vs standard RM driver
+detect_driver_type() {
+    # Use timeout to prevent hangs, and check /proc/modules as fallback
+    if command -v timeout >/dev/null 2>&1; then
+        # Use timeout command if available
+        if timeout 5 lsmod 2>/dev/null | grep -q "^mods "; then
+            echo "Running MODs Driver on GPUs"
+        elif timeout 5 lsmod 2>/dev/null | grep -q "^nvidia "; then
+            echo "Running RM Driver on GPUs"
+        else
+            echo "GPU Driver not installed?"
+        fi
+    else
+        # Fallback: check /proc/modules directly (safer than lsmod)
+        if [ -r /proc/modules ]; then
+            if grep -q "^mods " /proc/modules 2>/dev/null; then
+                echo "Running MODs Driver on GPUs"
+            elif grep -q "^nvidia " /proc/modules 2>/dev/null; then
+                echo "Running RM Driver on GPUs"
+            else
+                echo "GPU Driver not installed?"
+            fi
+        else
+            echo "GPU Driver not installed?"
+        fi
+    fi
+}
+
 # Function to discover available IB devices
 discover_ib_devices() {
     ib_devices=""
@@ -514,7 +542,36 @@ run_query_file() {
 
 fetch_software_firmware_versions() {
     run_query "vulkaninfo"     "--version" "Vulkan Info"
-    run_query "nvidia-smi"     "--version" "NVIDIA SMI"
+    
+    # Detect driver type (MODs vs RM)
+    driver_type=$(detect_driver_type)
+    
+    # Skip nvidia-smi calls in safe mode to avoid hangs when driver is not responding
+    if [ $BUG_REPORT_SAFE_MODE -eq 0 ]; then
+        run_query "nvidia-smi"     "--version" "NVIDIA SMI"
+        run_query "nvidia-smi"     "--query-gpu=name,driver_version,memory.total,vbios_version,pci.bus_id,serial --format=csv,noheader" \
+                                   "NVIDIA GPU Details"
+    else
+        # In safe mode, try to get driver version from modinfo as fallback
+        if command -v modinfo >/dev/null 2>&1; then
+            driver_version=$(modinfo nvidia 2>/dev/null | grep "^version:" | awk '{print $2}')
+            if [ -n "$driver_version" ]; then
+                store_result "NVIDIA SMI" "Driver version (from modinfo): $driver_version"
+            else
+                store_result "NVIDIA SMI" "Unable to fetch (safe mode - driver may be hung)"
+            fi
+        else
+            store_result "NVIDIA SMI" "Unable to fetch (safe mode - driver may be hung)"
+        fi
+        
+        # Provide specific messaging for MODs driver
+        if echo "$driver_type" | grep -q "MODs Driver"; then
+            store_result "NVIDIA GPU Details" "Skipped in safe mode (MODs driver detected - nvidia-smi may hang)"
+        else
+            store_result "NVIDIA GPU Details" "Skipped in safe mode (driver may be hung)"
+        fi
+    fi
+    
     run_query "nvidia-settings" "--version" "NVIDIA Settings"
     run_query "nv-fabricmanager" "--version" "NVIDIA Fabric Manager"
     run_query "opensm"         "--version" "NVIDIA Subnet Manager"
@@ -523,8 +580,6 @@ fetch_software_firmware_versions() {
     run_query "ibnetdiscover"  "--version" "InfiniBand Network Discovery"
     run_query_file "/var/log/dmesg" "MSE\|uCode\|NETIR" "NVIDIA MSE/NETIR Versions"
 
-    run_query "nvidia-smi"     "--query-gpu=name,driver_version,memory.total,vbios_version,pci.bus_id,serial --format=csv,noheader" \
-                               "NVIDIA GPU Details"
     run_query_mlxlink "NVIDIA Switch Details" "Quantum"
     run_query_ibv_devinfo "NVIDIA NIC Details"
 
@@ -616,7 +671,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 36557123 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 36717326 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -1010,6 +1065,59 @@ echo -n "Running $(basename $0)...";
     fetch_software_firmware_versions
 ) | $GZIP_CMD >> $LOG_FILENAME
 
+# Add driver type detection information (only if not in safe mode to avoid hangs)
+if [ $BUG_REPORT_SAFE_MODE -eq 0 ]; then
+    # Show driver type on console
+    driver_type=$(detect_driver_type)
+    echo ""
+    echo "Detected driver type: $driver_type"
+    if echo "$driver_type" | grep -q "MODs Driver"; then
+        echo ""
+        echo "WARNING: MODs driver detected. nvidia-smi may hang with MODs driver."
+        echo "If experiencing hangs, try:"
+        echo "  sudo rmmod mods"
+        echo "  sudo modprobe nvidia"
+        echo "  sudo nvidia-smi  # confirm RM driver is working"
+        echo "  then run nvidia-bug-report.sh"
+    fi
+    
+    # Also log detailed info to file
+    (
+        echo "____________________________________________"
+        echo ""
+        echo "NVIDIA Driver Type Detection:"
+        echo ""
+        echo "Detected driver type: $driver_type"
+        if echo "$driver_type" | grep -q "MODs Driver"; then
+            echo ""
+            echo "nvidia-smi does not work with MODs driver."
+            echo "Install RM Driver using these instructions:"
+            echo "  sudo rmmod mods"
+            echo "  sudo modprobe nvidia"
+            echo "  sudo nvidia-smi  # confirm RM driver is working"
+            echo "  then run nvidia-bug-report.sh"
+        elif echo "$driver_type" | grep -q "RM Driver"; then
+            echo "Standard RM driver detected."
+        else
+            echo "No NVIDIA driver modules detected."
+        fi
+        echo ""
+    ) | $GZIP_CMD >> $LOG_FILENAME
+else
+    # Show safe mode message on console
+    echo "Skipped driver type detection (safe mode - driver may be unresponsive)"
+    
+    # Also log to file
+    (
+        echo "____________________________________________"
+        echo ""
+        echo "NVIDIA Driver Type Detection:"
+        echo ""
+        echo "Skipped in safe mode"
+        echo ""
+    ) | $GZIP_CMD >> $LOG_FILENAME
+fi
+
 if [ $BUG_REPORT_SAFE_MODE -eq 0 ]; then
     # List the sysfs entries for all NVIDIA device functions
     # This info is useful to debug dynamic power management issues
@@ -1067,6 +1175,11 @@ append_silent "/etc/yellowdog-release"
 append_silent "/etc/sun-release"
 append_silent "/etc/release"
 append_silent "/etc/gentoo-release"
+append_silent "/etc/lsb-release"
+append_silent "/etc/os-release"
+append_silent "/etc/fastos-release"
+append_silent "/etc/fastos-ota"
+append_silent "/etc/dgx-release"
 
 
 
@@ -1713,7 +1826,7 @@ done
     echo ""
 
     if [ -d "/sys/class/drm" ]; then
-        for CARD in /sys/class/drm/*/device/driver ; do
+        for CARD in `find -L /sys/class/drm -maxdepth 3 -path "*/device/driver" 2>/dev/null`; do
             echo_metadata $CARD
         done
     else
@@ -1724,6 +1837,35 @@ done
 
 ) | $GZIP_CMD >> $LOG_FILENAME
 
+# List some info about DRM nodes
+(
+    if [ -d "/sys/class/drm" ]; then
+        for DRM_NODE in /sys/class/drm/* ; do
+            DRIVERPATH="$DRM_NODE/device/device/driver"
+            if [ -e "$DRIVERPATH" ]; then
+                REALPATH=$(readlink -f "$DRIVERPATH")
+                case "$REALPATH" in 
+                    */drivers/nvidia)
+                        for DRM_SUBPATH in enabled status dpms modes; do
+                            if [ -e "$DRM_NODE/$DRM_SUBPATH" ]; then
+                                append  "$DRM_NODE/$DRM_SUBPATH"
+                            fi
+                        done
+                        if [ -e "$DRM_NODE/edid" ]; then
+                            append_binary_file  "$DRM_NODE/edid"
+                        fi
+                        ;; 
+                esac
+            fi
+        done
+    else
+        echo "/sys/class/drm not present"
+    fi
+
+    echo ""
+
+) | $GZIP_CMD >> $LOG_FILENAME
+
 # List the mapping of PCI devices to DRM device files, and the existence and
 # permissions of the DRM device files themselves.
 (
